==> crow-2.15.0.tar.bz2: crow-2.15.0/designer/main.cpp <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2009 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person
 *  obtaining a copy of this software and associated documentation
 *  files (the "Software"), to deal in the Software without
 *  restriction, including without limitation the rights to use, copy,
 *  modify, merge, publish, distribute, sublicense, and/or sell copies
 *  of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind,
 *  express or implied, including but not limited to the warranties of
 *  merchantability, fitness for a particular purpose and
 *  noninfringement. In no event shall the authors or copyright
 *  holders be liable for any claim, damages or other liability,
 *  whether in an action of contract, tort or otherwise, arising from,
 *  out of or in connection with the software or the use or other
 *  dealings in the software.
 */

#include "headers.h"
#include "application.h"

namespace CrowApp {

int Main(int argc, char ** argv) {

	CHECK(CROW_VERSION/1000 <= crow_version()/1000);

	std::vector<std::string> args1= Arguments(argc, argv);
	Gtk::Main gtkmain(&argc, &argv);
	std::vector<std::string> args2= Arguments(argc, argv);

	crow_enter_check("main()");
	{
		Application application(args1, args2);
		Gtk::Main::run(*application.getWindow());
	}
	crow_leave();

	return 0;
}

int TryMain(int argc, char ** argv) {
	Glib::ustring msg;
	try {
		return Main(argc, argv);
	} catch(const Glib::Exception & x) {
		msg= x.what();
	} catch(...) {
		msg= "Unknown exception";
	}
	FatalError(msg);
	return 0;
}

}

#ifdef _WIN32
	int WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
		{ return CrowApp::TryMain(__argc, __argv); }
#else
	int main(int argc, char ** argv)
		{ return CrowApp::TryMain(argc, argv); }
#endif

==> crow-2.17.1.tar.bz2: crow-2.17.1/designer/main.cpp <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2010 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person
 *  obtaining a copy of this software and associated documentation
 *  files (the "Software"), to deal in the Software without
 *  restriction, including without limitation the rights to use, copy,
 *  modify, merge, publish, distribute, sublicense, and/or sell copies
 *  of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind,
 *  express or implied, including but not limited to the warranties of
 *  merchantability, fitness for a particular purpose and
 *  noninfringement. In no event shall the authors or copyright
 *  holders be liable for any claim, damages or other liability,
 *  whether in an action of contract, tort or otherwise, arising from,
 *  out of or in connection with the software or the use or other
 *  dealings in the software.
 */

#include "headers.h"
#include "application.h"

namespace CrowApp {

int Main(int argc, char ** argv) {

	CHECK(CROW_VERSION/1000 <= GetCrowVersion()/1000);

	std::vector<std::string> args1= Arguments(argc, argv);
	Gtk::Main gtkmain(&argc, &argv);
	std::vector<std::string> args2= Arguments(argc, argv);

	#if ENABLE_NLS
		bindtextdomain(PACKAGE, LOCALEDIR);
		bind_textdomain_codeset(PACKAGE, "UTF-8");
		textdomain(PACKAGE);
	#endif

	Enter enter;
	{
		Application application(args1, args2);
		Gtk::Main::run(*application.getWindow());
	}

	return 0;
}

int TryMain(int argc, char ** argv) {
	try {
		return Main(argc, argv);
	} catch(...) {
		UnhandledException();
	}
	return 0;
}

}

#ifdef _WIN32
	int WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
		{ return CrowApp::TryMain(__argc, __argv); }
#else
	int main(int argc, char ** argv)
		{ return CrowApp::TryMain(argc, argv); }
#endif
